@@ -50,7 +50,7 @@ from injection._core.common.asynchronous import (
 from injection._core.common.event import Event, EventChannel, EventListener
 from injection._core.common.invertible import Invertible, SimpleInvertible
 from injection._core.common.key import new_short_key
-from injection._core.common.lazy import Lazy, lazy
+from injection._core.common.lazy import Lazy, alazy, lazy
 from injection._core.common.threading import get_lock
 from injection._core.common.type import (
     InputType,
@@ -337,12 +337,14 @@ class Locator(Broker):
         cls: InputType[T],
     ) -> bool:
         new_mode, existing_mode = new.mode, existing.mode
-        is_override = new_mode == Mode.OVERRIDE
 
-        if new_mode == existing_mode and not is_override:
+        if new_mode == Mode.OVERRIDE:
+            return True
+
+        elif new_mode == existing_mode:
             raise RuntimeError(f"An injectable already exists for the class `{cls}`.")
 
-        return is_override or new_mode.rank > existing_mode.rank
+        return new_mode.rank > existing_mode.rank
 
     @staticmethod
     def __standardize_inputs[T](
@@ -481,13 +483,12 @@ class Module(Broker, EventListener):
                 injectable_class = SimpleScopedInjectable
                 hint = wrapper = wrapped  # type: ignore[assignment]
 
-            hints = on if hint is None else (hint, on)
             self.injectable(
                 wrapper,
                 cls=partial(injectable_class, scope_name=scope_name),
                 ignore_type_hint=True,
                 inject=inject,
-                on=hints,
+                on=(hint, on),
                 mode=mode,
             )
             return wrapped
@@ -512,9 +513,9 @@ class Module(Broker, EventListener):
         mode: Mode | ModeStr = Mode.get_default(),
     ) -> Any:
         def decorator(wp: Recipe[P, T]) -> Recipe[P, T]:
-            lazy_instance = lazy(wp)
+            recipe: Recipe[[], T] = alazy(wp) if iscoroutinefunction(wp) else lazy(wp)  # type: ignore[arg-type]
             self.injectable(
-                lambda: ~lazy_instance,
+                recipe,
                 ignore_type_hint=True,
                 inject=False,
                 on=(wp, on),
